@@ -5,6 +5,7 @@
  * --------------------------------------------------------------------------
  */
 
+
  $(document).ready( function() {
 
     let dashboardStatus = {};
@@ -17,6 +18,17 @@
         },
     })
 
+    // Load table
+    my_table = inittable("jobs?order=desc&limit=10&sortby=last_update")
+    
+    // Add action to refresh button
+    $("#refresh").click(my_table.ajax.reload)
+
+    // Adjust buttons
+    let tableButtons = document.getElementsByClassName("dt-buttons")
+    tableButtons[0].className = "row justify-content-end"
+
+
     // Load info into divs
     document.getElementById('num-jobs-in-dashboard').textContent = dashboardStatus.jobs.total
     document.getElementById('num-jobs-running').textContent = dashboardStatus.jobs.running
